.. _index:

DryMass is a Python library and a command-line tool for manipulating
and analyzing quantitative phase microscopy images of cell-sized objects.
This is the documentation of DryMass version |release|.


Documentation
=============

.. toctree::
   :maxdepth: 2

   sec_introduction
   sec_theory_notes
   sec_getting_started
   sec_tutorials
   sec_examples
   sec_code_reference

.. toctree::
   :maxdepth: 1

   sec_changelog
   zsec_bib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

